@@ -1,15 +1,15 @@
 # 配置模块
 # author: OPN48/cuba3
-# github: https://github.com/OPN48/pyLunarCalendar
-starZodiacName = ('摩羯座', '水瓶座', '双鱼座', '白羊座', '金牛座', '双子座', '巨蟹座', '狮子座', '处女座', '天秤座', '天蝎座', '射手座')
-starZodiacDate = ((1, 20), (2, 19), (3, 21), (4, 21), (5, 21), (6, 22), (7, 23), (8, 23), (9, 23), (10, 23), (11, 23), (12, 23))
+# github: https://github.com/OPN48/cnLunar
+STAR_ZODIAC_NAME = ('摩羯座', '水瓶座', '双鱼座', '白羊座', '金牛座', '双子座', '巨蟹座', '狮子座', '处女座', '天秤座', '天蝎座', '射手座')
+STAR_ZODIAC_DATE = ((1, 20), (2, 19), (3, 21), (4, 21), (5, 21), (6, 22), (7, 23), (8, 23), (9, 23), (10, 23), (11, 23), (12, 23))
 
 START_YEAR = 1901
-month_DAY_BIT = 12
-month_NUM_BIT = 13
+MONTH_DAY_BIT = 12
+LEAPMONTH_NUM_BIT = 13
 stc = '小寒大寒立春雨水惊蛰春分清明谷雨立夏小满芒种夏至小暑大暑立秋处暑白露秋分寒露霜降立冬小雪大雪冬至'
-solarTermsNameList = [stc[x * 2:(x + 1) * 2] for x in range(0, len(stc) // 2)]
-eastZodiacList = ['玄枵', '娵訾', '降娄', '大梁', '实沈', '鹑首', '鹑火', '鹑尾', '寿星', '大火', '析木', '星纪']
+SOLAR_TERMS_NAME_LIST = [stc[x * 2:(x + 1) * 2] for x in range(0, len(stc) // 2)]
+EAST_ZODIAC_LIST = ['玄枵', '娵訾', '降娄', '大梁', '实沈', '鹑首', '鹑火', '鹑尾', '寿星', '大火', '析木', '星纪']
 the10HeavenlyStems = ['甲', '乙', '丙', '丁', '戊', '己', '庚', '辛', '壬', '癸']
 the10HeavenlyStems5ElementsList = ['木', '木', '火', '火', '土', '土', '金', '金', '水', '水']
 the12EarthlyBranches = ['子', '丑', '寅', '卯', '辰', '巳', '午', '未', '申', '酉', '戌', '亥']
@@ -54,13 +54,14 @@ lunarDayNameList = ['初一', '初二', '初三', '初四', '初五', '初六',
 upperNum = ['零', '一', '二', '三', '四', '五', '六', '七', '八', '九']
 weekDay = ['星期一', '星期二', '星期三', '星期四', '星期五', '星期六', '星期日']
 
-# 1901-2100年二十节气最小公差数序列 向量压缩法
-encryptionVectorList = [4, 19, 3, 18, 4, 19, 4, 19, 4, 20, 4, 20, 6, 22, 6, 22, 6, 22, 7, 22, 6, 21, 6, 21]
+# 1901-2100年二十节气最小数序列 向量压缩法
+ENC_VECTOR_LIST = [4, 19, 3, 18, 4, 19, 4, 19, 4, 20, 4, 20, 6, 22, 6, 22, 6, 22, 7, 22, 6, 21, 6, 21]
 # 1901-2100年二十节气数据 每个元素的存储格式如下：
+# https://www.hko.gov.hk/sc/gts/time/conversion.htm
 # 1-24
-# 节气所在天（减去节气最小公约数）
+# 节气所在天（减去节气最小数）
 # 1901-2100年香港天文台公布二十四节气按年存储16进制，1个16进制为4个2进制
-solarTermsData = [
+SOLAR_TERMS_DATA_LIST = [
     0x6aaaa6aa9a5a, 0xaaaaaabaaa6a, 0xaaabbabbafaa, 0x5aa665a65aab, 0x6aaaa6aa9a5a,  # 1901 ~ 1905
     0xaaaaaaaaaa6a, 0xaaabbabbafaa, 0x5aa665a65aab, 0x6aaaa6aa9a5a, 0xaaaaaaaaaa6a,
     0xaaabbabbafaa, 0x5aa665a65aab, 0x6aaaa6aa9a56, 0xaaaaaaaa9a5a, 0xaaabaabaaeaa,
@@ -103,8 +104,8 @@ solarTermsData = [
     0x15, 0x100110500, 0x55110510501, 0x155551554505, 0x555555555515]
 
 # 农历数据 每个元素的存储格式如下：
-#   16~13    12          11~0
-#  闰几月 闰月日数  12-1月份农历日数 0=29天 1=30天
+#   17~14    13          12~1
+#  闰几月 闰月日数  12-1 月份农历日数 0=29天 1=30天
 lunarMonthData = [
     0x00752, 0x00ea5, 0x0ab2a, 0x0064b, 0x00a9b, 0x09aa6, 0x0056a, 0x00b59, 0x04baa, 0x00752,  # 1901 ~ 1910
     0x0cda5, 0x00b25, 0x00a4b, 0x0ba4b, 0x002ad, 0x0056b, 0x045b5, 0x00da9, 0x0fe92, 0x00e92,  # 1911 ~ 1920
@@ -163,3 +164,57 @@ twohourLuckyTimeList = [
 thingsSort = ['祭祀', '出行', '移徙', '结婚姻', '宴会', '嫁娶', '安床', '沐浴', '剃头', '修造', '求医疗病', '上表章', '上官', '入学', '冠带', '进人口',
               '裁衣', '竖柱上梁', '经络', '开市', '立券', '交易', '纳财', '修置产室', '开渠', '穿井', '安碓硙', '扫舍宇', '平治道涂', '破屋坏垣', '伐木', '捕捉',
               '畋猎', '栽种', '牧养', '破土', '安葬', '启攒']
+
+# 神煞宜忌准备
+bujiang = ['壬寅壬辰辛丑辛卯辛巳庚寅庚辰丁丑丁卯丁巳戊寅戊辰', '辛丑辛卯庚子庚寅庚辰丁丑丁卯丙子丙寅丙辰戊子戊寅戊辰', '辛亥辛丑辛卯庚子庚寅丁亥丁丑丁卯丙子丙寅戊子戊寅',
+           '庚戌庚子庚寅丁亥丁丑丙戌丙子丙寅乙亥乙丑戊戌戊子戊寅', '丁酉丁亥丁丑丙戌丙子乙酉乙亥乙丑甲戌甲子戊戌戊子', '丁酉丁亥丙申丙戌丙子乙酉乙亥甲申甲戌甲子戊申戊戌戊子',
+           '丙申丙戌乙未乙酉乙亥甲申甲戌癸未癸酉癸亥戊申戊戌', '乙未乙酉甲午甲申甲戌癸未癸酉壬午壬申壬戌戊午戊申戊戌', '乙巳乙未乙酉甲午甲申癸巳癸未癸酉壬午壬申戊午戊申',
+           '甲辰甲午甲申癸巳癸未壬辰壬午壬申辛巳辛未戊辰戊午戊申', '癸卯癸巳癸未壬辰壬午辛卯辛巳辛未庚辰庚午戊辰戊午', '癸卯癸巳壬寅壬辰壬午辛卯辛巳庚寅庚辰庚午戊寅戊辰戊午']
+
+officerThings = {
+            '建': (['施恩', '招贤', '举正直', '出行', '上官', '临政'], []),
+            '除': (['解除', '沐浴', '整容', '剃头', '整手足甲', '求医疗病', '扫舍宇'], []),
+            '满': (['进人口', '裁制', '竖柱上梁', '经络', '开市', '立券交易', '纳财', '开仓', '塞穴', '补垣'],
+                  ['施恩', '招贤', '举正直', '上官', '临政', '结婚姻', '纳采', '求医疗病']),
+            '平': (['修饰垣墙', '平治道涂'],
+                  ['祈福', '求嗣', '上册', '上表章', '颁诏', '施恩', '招贤', '举正直', '宣政事', '布政事', '庆赐', '宴会', '冠带', '出行', '安抚边境', '选将',
+                   '出师', '上官', '临政', '结婚姻', '纳采', '嫁娶', '进人口', '搬移', '安床', '解除', '求医疗病', '裁制', '营建', '修宫室', '缮城郭',
+                   '筑堤防', '修造', '竖柱上梁', '修仓库', '鼓铸', '经络', '酝酿', '开市', '立券交易', '纳财', '开仓', '修置产室', '开渠', '穿井', '栽种',
+                   '牧养', '纳畜', '破土', '安葬', '启攒']),
+            '定': (['冠带'], []),
+            '执': (['捕捉'], []),
+            '破': (['求医疗病'], []),
+            '危': (['安抚边境', '选将', '安床'], []),
+            '成': (['入学', '安抚边境', '搬移', '筑堤防', '开市'], []),
+            '收': (['进人口', '纳财', '捕捉', '纳畜'],
+                  ['祈福', '求嗣', '上册', '上表章', '颁诏', '施恩', '招贤', '举正直', '宣政事', '布政事', '庆赐', '宴会', '冠带', '出行', '安抚边境', '选将',
+                   '出师', '上官', '临政', '结婚姻', '纳采', '嫁娶', '搬移', '安床', '解除', '求医疗病', '裁制', '营建', '修宫室', '缮城郭', '筑堤防', '修造',
+                   '竖柱上梁', '鼓铸', '经络', '酝酿', '开市', '立券交易', '开仓', '修置产室', '开渠', '穿井', '破土', '安葬', '启攒']),
+            '开': (
+                ['祭祀', '祈福', '求嗣', '上册', '上表章', '颁诏', '覃恩', '施恩', '招贤', '举正直', '恤孤茕', '宣政事', '雪冤', '庆赐', '宴会', '入学',
+                 '出行',
+                 '上官', '临政', '搬移', '解除', '求医疗病', '裁制', '修宫室', '缮城郭', '修造', '修仓库', '开市', '修置产室', '开渠', '穿井', '安碓硙', '栽种',
+                 '牧养'], []),
+            '闭': (['筑堤防', '塞穴', '补垣'],
+                  ['上册', '上表章', '颁诏', '施恩', '招贤', '举正直', '宣政事', '布政事', '庆赐', '宴会', '出行', '出师', '上官', '临政', '结婚姻', '纳采',
+                   '嫁娶', '进人口', '搬移', '安床', '求医疗病', '疗目', '营建', '修宫室', '修造', '竖柱上梁', '开市', '开仓', '修置产室', '开渠', '穿井']),
+        }
+
+day8CharThing = {
+    '甲': ([], ['开仓']),
+    '乙': ([], ['栽种']),
+    '丁': ([], ['整容', '剃头']),
+    '庚': ([], ['经络']),
+    '辛': ([], ['酝酿']),
+    '壬': ([], ['开渠', '穿井']),
+    '子': (['沐浴'], []),  # 亥子日宜沐浴
+    '丑': ([], ['冠带']),
+    '寅': ([], ['祭祀']),
+    '卯': ([], ['穿井']),
+    '酉': ([], ['宴会']),
+    '巳': ([], ['出行']),
+    '午': ([], ['苫盖']),
+    '未': ([], ['求医疗病']),
+    '申': ([], ['安床']),
+    '亥': (['沐浴'], ['嫁娶'])  # 亥子日宜沐浴
+}
\ No newline at end of file
